@@ -118,7 +118,7 @@ class Products extends CGExtensions
 
   function GetVersion()
   {
-	return '2.12.1';
+	return '2.13.3';
   }
 
   function MinimumCMSVersion()
@@ -493,7 +493,7 @@ EOT;
   // deprecated
   function GetFieldDefs($admin = false,$public = true)
   {
-	if( !is_array($this->_fflddef_cache) )
+	if( !is_array($this->_flddef_cache) )
 	  {
 		$entryarray = array();
 		$db = cmsms()->GetDB();
@@ -537,7 +537,7 @@ EOT;
 		  }
 		$this->_flddef_cache = $entryarray;
 	  }
-
+		
 	return $this->_flddef_cache;
   }
 
@@ -545,7 +545,6 @@ EOT;
   // deprecated, move to class
   function GetFieldDefsForProduct($id,$admin = false,$public = true)
   {
-	$entryarray = array();
 
 	global $gCms;
 	$db =& $gCms->GetDB();
@@ -565,26 +564,30 @@ EOT;
 	  {
 		$query = 'SELECT b.* FROM  '.cms_db_prefix().'module_products_fielddefs a, '.cms_db_prefix().'module_products_fieldvals b WHERE a.id = b.fielddef_id AND a.admin_only <= 0 and b.product_id = ?';
 	  }
-	$dbresult = $db->Execute($query, array($id));
-	while ($dbresult && $row = $dbresult->FetchRow())
+	$dbresult = $db->GetArray($query, array($id));
+
+	$res = array();
+	foreach( $entryarray as $entry )
 	  {
-		$count = 0;
-		foreach ($entryarray as $field)
+		$newentry = clone $entry;		
+		foreach ($dbresult as $row)
 		  {
-			if ($row['fielddef_id'] == $field->id)
+			if ($row['fielddef_id'] == $newentry->id)
 			  {
-				$entryarray[$count]->fielddef_id = $field->id;
-				if( $field->type == 'dimensions' || $field->type == 'subscription')
+				if( $newentry->type == 'dimensions' || $newentry->type == 'subscription')
 				  {
 					$row['value'] = unserialize($row['value']);
 				  }
-				$entryarray[$count]->value = $row['value'];
+				$newentry->value = $row['value'];
+				$newentry->fielddef_id = $newentry->id; // ??
+
+				break;
 			  }
-			$count++;
 		  }
+		$res[] = $newentry;
 	  }
 
-	return $entryarray;
+	return $res;
   }
 	
 
