@@ -168,7 +168,7 @@ if( !(is_array($productlist) && count($productlist) > 0) )
 		  {
 		    $fieldid = $fielddefs[$fieldname]->id;
 		    $as = 'FV'.$sortfield++;
-		    $joins[] = cms_db_prefix()."module_products_fieldvals {$as} ON c.id = {$as}.product_id AND $as.fielddef_id = '{$fieldid}'";
+		    $joins[] = cms_db_prefix()."module_products_fieldvals {$as} ON c.id = {$as}.product_id AND $as.fielddef_id = ".$db->qstr($fieldid);
 		    $sortby = "{$as}.value";
 		  }
 	      }
@@ -283,7 +283,7 @@ if( !(is_array($productlist) && count($productlist) > 0) )
 	$arr2 = array();
 	foreach( $arr1 as $xx )
 	  {
-	    $arr2[] = "'".$xx."'";
+	    $arr2[] = $db->qstr($xx);
 	  }
 	$txt = implode(',',$arr2);
 	$where[] = 'cs.name IN ('.$txt.')';
@@ -295,7 +295,7 @@ if( !(is_array($productlist) && count($productlist) > 0) )
 	$arr2 = array();
 	foreach( $arr1 as $xx )
 	  {
-	    $arr2[] = "'".$xx."'";
+	    $arr2[] = $db->qstr($xx);
 	  }
 	$txt = implode(',',$arr2);
 	$subquery = 'SELECT pc.product_id FROM '.cms_db_prefix().'module_products_product_categories pc
@@ -454,8 +454,9 @@ while ($dbresult && ($row = $dbresult->FetchRow()))
   // add custom fields
   $fielddefs = $this->GetFieldDefsForProduct($row['id'],true,true);
   $fields = array();
-  foreach( $fielddefs as $onedef )
+  foreach( $fielddefs as $tonedef )
     {
+      $onedef = clone $tonedef;
       if( $onedef->type == 'image' )
 	{
 	  if( isset($onedef->value) && file_exists(cms_join_path($filedir,'thumb_'.$onedef->value)) )
@@ -473,7 +474,7 @@ while ($dbresult && ($row = $dbresult->FetchRow()))
   $onerow->fields = $fields;
 
   // add categories
-  $catarray = $this->GetCategoriesForProduct($params['productid'],true,true);
+  $catarray = $this->GetCategoriesForProduct($parms['productid'],true,true);
   if( count($catarray) )
     {
       $catnamearray = array();
@@ -492,7 +493,7 @@ while ($dbresult && ($row = $dbresult->FetchRow()))
       $onerow->attributes = $tmp;
     }
 
-  $tmp = product_utils::get_product_attributes_full($params['product_id']);
+  $tmp = product_utils::get_product_attributes_full($parms['productid']);
   if( is_array($tmp) )
     {
       $onerow->attribs_full = $tmp;
@@ -501,7 +502,6 @@ while ($dbresult && ($row = $dbresult->FetchRow()))
   $entryarray[] = $onerow;
 }
 
-
 //
 // Give everything to smarty
 //
@@ -562,16 +562,6 @@ if( isset( $params['selectcategory'] ) )
 	$smarty->assign('catformend', $this->CreateFormEnd());
   }
 
-$cartmod = $this->GetPreference('cartmodule','');
-if( !empty($cartmod) )
-  {
-    $cmparams = $this->GetPreference('cartmoduleparams','');
-    if( !empty($cmparams) )
-      {
-	$str = sprintf("{%s %s}",$cartmod,$cmparams);
-	$smarty->assign('cart_module_tag',$str);
-      }
-  }
 $smarty->assign('currency_symbol',product_ops::get_currency_symbol());
 $smarty->assign('weight_units',product_ops::get_weight_units());
 
