@@ -152,6 +152,7 @@ if (isset($params['submit']))
     $duplicate = '';
     $duplicatesku = '';
     $duplicatealias = '';
+    $emptysku = '';
     if ($product_name != '')
       {
 	$query = 'SELECT id FROM '.cms_db_prefix().'module_products
@@ -170,6 +171,11 @@ if (isset($params['submit']))
 	$duplicatealias = $alias;
       }
 
+    if( empty($sku) && $this->GetPreference('skurequired') )
+      {
+	$emptysku = 1;
+      }
+
     if( !$duplicate && !empty($sku) )
       {
 	// check for duplicate sku
@@ -183,6 +189,10 @@ if (isset($params['submit']))
       {
 	echo $this->ShowErrors($this->Lang('error_product_nameused'));
       }
+    else if( $emptysku )
+      {
+	echo $this->ShowErrors($this->Lang('error_sku_required'));
+      }
     else if( $duplicatealias )
       {
 	echo $this->ShowErrors($this->Lang('error_product_aliasused'));
