@@ -259,7 +259,7 @@ function products_ProcessImage(&$mod,$srcname,$wmlocation='default')
       }
 
     // optional preview image
-    if( $mod->GetPreference('autopreview') == 1 )
+    if( $mod->GetPreference('autopreviewimg') == 1 )
       {
 		$destname = cms_join_path($destdir,'preview_'.$filename);
 		if( !file_exists($destname) )
