@@ -107,6 +107,7 @@ $lang['error_product_skuused'] = 'That SKU value is already in use by another pr
 $lang['error_price_adjustment'] = 'Invalid price adjustment value for item %s';
 $lang['error_sku_required'] = 'Please enter a unique SKU';
 $lang['error_upload_failed'] = 'Upload failed: %s';
+$lang['exclude_categories'] = 'Exclude products in the selected categories from the results';
 $lang['expire_six_months'] = 'After Six Months';
 $lang['expire_one_year'] = 'After One Year';
 $lang['expire_two_year'] = 'After Two Years';
@@ -270,9 +271,11 @@ $lang['no'] = 'No';
 $lang['nonamegiven'] = 'No name was supplied';
 $lang['nonamegiven'] = 'No name was supplied';
 $lang['none'] = 'None';
+$lang['nothing_selectd'] = 'Nothing selected';
 
 # O
 $lang['of'] = 'Of';
+$lang['operation_complete'] = 'Operation Complete';
 
 # P
 $lang['page'] = 'Page';
@@ -297,7 +300,7 @@ $lang['param_category'] = 'When used in the <em>default</em> summary mode, this
 $lang['param_categoryfield'] = 'Applicable only to the &quot;categorylist&quot; action, this parameter can be used to filter categories based on the value of a category field.  It will not work in conjunction with the &quot;category&quot; or &quot;category_id&quot; parameters.   The syntax of this parameter is a comma separated list of field names, and field values.  i.e:  categorylist=&quot;field name:value,field name 2:value 2&quot;';
 $lang['param_categorylisttemplate'] = 'Useful only with the categorylist and fieldlist actions, this parameter indicates the template that should be used for the display.  If no value is specified then the current default template of that type is used.';
 $lang['param_categorylistdtltemplate'] = 'Useful only with the categorylist actions, this parameter indicates the template that should be used for the display of the category details.  This uses a category list template..  If no value is specified then the current default template of that type is used.';
-$lang['param_detailpage'] = 'This specifies the pageid or alias that should be used to display the detail report.  It can be used with the <em>default</em> or search actions.';
+$lang['param_detailpage'] = 'This specifies the pageid or alias that should be used to display the detail report.  It can be used with the <em>default</em> or search actions.  This option is not compatible with pretty urls of any sort.';
 $lang['param_detailtemplate'] = 'This parameter specifies the template that should be used for the detail mode display.  If no value is specified, then the current default template of that type is used.  This parameter has no use when pretty urls are enabled.';
 $lang['param_excludecat'] = 'Applicable only to the default (summary) view, this parameter will allow excluding products that are in a specific category from the result. A comma separated list of category names is allowed. This parameter can work in conjunction with the category parameter to provide a list of the products that are in this category, but not in that category';
 $lang['param_field'] = 'Used only in the <em>fieldlist</em> this parameter is required to specify the name of a user defined property to create a list from.';
@@ -425,7 +428,10 @@ $lang['search_name'] = 'Search Property Name';
 $lang['search_price'] = 'Price Range';
 $lang['searchtemplate_addedit'] = 'Add/Edit Search Form Template';
 $lang['searchtemplates'] = 'Search Templates';
+$lang['select_all'] = 'Select All';
 $lang['select_one'] = 'Select One';
+$lang['setdraft'] = 'Set As Draft';
+$lang['setpublished'] = 'Set As Published';
 $lang['sku'] = 'SKU';
 $lang['sort_by'] = 'Sort By';
 $lang['sort_order'] = 'Sort Order';
@@ -474,6 +480,7 @@ $lang['viewable_fields'] = 'Select custom fields to view in the table';
 # W
 $lang['watermark_location'] = 'Watermark Location';
 $lang['weight'] = 'Weight';
+$lang['with_selected'] = 'With Selected';
 
 # X
 
