@@ -87,14 +87,16 @@ $lang['error_missingparam'] = 'Ein ben&ouml;tigter Parameter fehlt oder ist ung&
 $lang['error_nameused'] = 'An Element mit diesem Namen existiert bereits';
 $lang['error_nofieldtype'] = 'Bitte w&auml;hlen Sie einen Feldtyp';
 $lang['error_noname'] = 'Sie m&uuml;ssen einen Namen angeben';
-$lang['error_onesubscriptionfield'] = 'Only one subscription field is allowed';
+$lang['error_onesubscriptionfield'] = 'Es kann nur ein Abonnement-Feld angelegt werden';
 $lang['error_permissiondenied'] = 'Berechtigung verweigert';
 $lang['error_product_aliasused'] = 'Der eingegebene Alias wird bereits verwendet';
 $lang['error_product_nameused'] = 'Ein Artikel mit diesem Namen existiert bereits';
 $lang['error_product_notfound'] = 'Das angefragte Produkt konnte nicht gefunden werden';
 $lang['error_product_skuused'] = 'Diese Artikelnummer wird bereits von einem anderen Artikel verwendet';
 $lang['error_price_adjustment'] = 'Ung&uuml;ltige Preis-Angaben f&uuml;r das Element %s';
+$lang['error_sku_required'] = 'Bitte eine eindeutige Artikelnummer eingeben';
 $lang['error_upload_failed'] = 'Das Hochladen ist fehlgeschlagen: %s';
+$lang['exclude_categories'] = 'Produkte aus den gew&auml;hlten Kategorieen nicht im Ergebnis anzeigen';
 $lang['expire_six_months'] = 'Nach sechs Monaten';
 $lang['expire_one_year'] = 'Nach einem Jahr';
 $lang['expire_two_year'] = 'Nach zwei Jahren';
@@ -153,6 +155,14 @@ $lang['help'] = '<h3>Was macht dieses Modul?</h3>
 <p>Die einfachste Variante ist es, den <strong>{Products}</strong> Tag in den Inhalts-Textbereich oder in einem Template einzuf&uuml;gen.</p>
 <p>Wenn Sie das Verhalten dieses Moduls nach Ihren W&uuml;nschen anpassen wollen, k&ouml;nnen Sie verschiedene Parameter zum <strong>{Products}</strong> Tag hinzuf&uuml;gen. Die komplette Liste der Parameter finden Sie weiter unten im Text. Wenn Sie zum Beispiel eine Liste von Produkten einer Kategorie anzeigen wollen, k&ouml;nnen Sie den Tag wie folgt verwenden: <code>{Products category=&#039;categoryname&#039;}</code></p>
 </ul>
+<h3>Smarty Plugins</h3>
+<p>Dieses Modul erweitert Smarty um ein oder mehrere Plugins, die das Einf&uuml;gen von Artikeldaten in die Templates vereinfachen:</p>
+<ul>
+  <li><code>{products_getcategory categoryid=&#039;99&#039; [assign=&#039;tmp&#039;]}</code>
+  <p>Das Plugin liefert die kompletten Daten zu einer Kategorie-ID und weisst diese der ggf. angegebenen Smarty Variablen zu.  Der R&uuml;ckgabewert ist ein Objekt mit allen Daten einer Kategorie, inklusive der Feldwerte.<br/>Bsp.: <code>{products_getcategory categoryid=1 assign=&#039;tmp&#039;}Category name = {$tmp->name}</code></p>
+  </li>
+</ul>
+
 <h3>Support</h3>
 <p>Dieses Modul beinhaltet keinen kommerziellen Support. Es existieren jedoch eine Reihe von Ressourcen, die Ihnen bei diesem Modul helfen k&ouml;nnen:</p>
 <ul>
@@ -160,35 +170,45 @@ $lang['help'] = '<h3>Was macht dieses Modul?</h3>
 <li>Um kommerziellen Support zu erhalten, senden Sie eine EMail zum Author <a href="mailto:calguy1000@cmsmadesimple.org">Robert Campbell</a>.</li>
 <li>Zus&auml;tzliche Diskussionen &uuml;ber dieses Modul finden Sie im CMS made simple Forum: <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forum</a>.</li>
 <li>F&uuml;r Fragen oder beschr&auml;nkten technischen Support kann der Author via IRC erreicht werden: <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
-</ul>';
+</ul>
+<h3>Urheberrecht und Lizenz:</h3>
+<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. Alle Rechte vorbehalten.</p>
+<p>Dieses Programm ist freie Software. Sie k&ouml;nnen es unter den Bedingungen der GNU General Public License, wie von der Free Software Foundation ver&ouml;ffentlicht, weitergeben und/oder modifizieren, entweder gem&auml;&szlig; Version 2 der Lizenz oder (nach Ihrer Option) jeder sp&auml;teren Version.</p>
+<p>Doch da diese Software ein Zusatzmodul zu CMS Made Simple ist gilt eine besondere Ausnahme zur GPL. 
+Sie d&uuml;rfen diese Software in keiner Version von CMS Made Simple einsetzen die nicht unter der GPL lizensiert ist, oder im Administrationsbereich nicht klar und deutlich darauf hinweist, das die Site mit CMS Made Simple erstellt wurde.</p>
+<p>Die Ver&ouml;ffentlichung dieses Programms erfolgt in der Hoffnung, da&szlig; es Ihnen von Nutzen sein wird, aber OHNE IRGENDEINE GARANTIE, sogar ohne die implizite Garantie der MARKTREIFE oder der VERWENDBARKEIT F&Uuml;R EINEN BESTIMMTEN ZWECK. Details finden Sie in der GNU General Public License.</p>
+<p>Sie sollten ein Exemplar der GNU General Public License zusammen mit diesem Programm erhalten haben. Falls nicht, schreiben Sie an die Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA oder lesen Sie sie <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
 $lang['hierarchy'] = 'Hierarchie';
 $lang['hierarchy_position'] = 'Hierarchie-Position';
+$lang['hierarchy_settings'] = 'Hierarchie-Einstellungen';
 $lang['id'] = 'ID';
 $lang['imagetext'] = 'Bild';
 $lang['image_handling_settings'] = 'Einstellungen f&uuml;r die Bilderverwaltung';
 $lang['import_from_csv'] = 'Produkte aus einer CSV-Datei importieren';
-$lang['inches'] = 'Inches';
+$lang['inches'] = 'Zoll';
 $lang['include_children'] = 'Einschlie&szlig;lich Unterpunkte?';
 $lang['info_alnumonly'] = 'Nur alphanumerische Zeichen. Keine Leerzeichen, Zitate oder Buchstaben/Nummern-Kombinationen';
 $lang['info_attribtemplate'] = 'M&ouml;gliche Variablen sind: {$attrib_text},{$attrib_adjust},{$currency_symbol}';
-$lang['info_attributes_copied'] = 'Atribute Kopiert';
+$lang['info_attributes_copied'] = 'Atribute kopiert';
 $lang['info_autowatermark'] = 'Es werden die Wasserzeichen-Einstellungen des CGExtensions-Moduls verwendet';
-$lang['info_batchsize'] = 'Set the number of lines to process per &quot;batch&quot;.  After a batch is complete, the importer will redirect, and resume operations.  If you are experiencing memory errors, or timeout problems due to large amounts of processing, you may need to consult your host provider, or reduce this number';
+$lang['info_batchsize'] = 'Geben Sie die Anzahl der Zeilen an, die pro &quot;Block&quot; verarbeitet werden sollen. Nachdem ein Block abgearbeitet ist, wird der Import weitergeleitet und verarbeitet den n&auml;chsten Block.  Wenn bei Ihnen Speicherfehler oder Zeit&uuml;berschreitungen aufgrund der Gr&ouml;&szlig;e der verarbeiteten Datenmenge auftreten, wenden Sie sich an Ihren Hosting-Provider oder verkleinern Sie die Zeilenanzahl';
 $lang['info_cart_module_params'] = 'Diese Parameter werden verwendet, um ein Warenkorb-Modul f&uuml;r die Artikel-Detail- und -Listenansicht auszuw&auml;hlen.';
-$lang['info_copy_attribsets'] = 'This action will copy Attribute sets (excluding sku values) from another product.';
+$lang['info_copy_attribsets'] = 'Hiermit kopieren Sie den Attributsatz (ohne Artikelnummer) eines anderen Artikels.';
 $lang['info_createfields'] = 'Unbekannte Artikelfelder automatisch erstellen? <em>(werden als Textfelder erstellt)</em>';
-$lang['info_createcategories'] = 'Automatically create product categories to match those of the CSV file, if it does not already exist';
-$lang['info_createhierarchy'] = 'Automatically create product hierarchies to match those of the CSV file if it does not already exist';
+$lang['info_createcategories'] = 'In der CSV-Datei angegebene, aber bisher fehlende Artikelkategorien automatisch erzeugen';
+$lang['info_createhierarchy'] = 'In der CSV-Datei angegebene, aber bisher fehlende Artikelhierarchien automatisch erzeugen';
 $lang['info_decimal_units'] = 'Dieses System versteht (.) als Dezimalstellen-Trennzeichen, z.B.: <strong>5.25</strong>';
 $lang['info_delimiter'] = 'Legen Sie hier das (oder die) Zeichen fest, die die Felder voneinander trennen';
-$lang['info_duplicateproducts'] = 'Specify how the system should handle a product whos name already exists in the CSV file';
+$lang['info_duplicateproducts'] = 'Legen Sie fest wie Artikel behandelt werden, deren Name schon in der CSV Datei vorhanden ist';
 $lang['info_fielddefs_tab'] = '<strong>Achtung: </strong> Alle Felder, die hier definiert werden, sind f&uuml;r alle Artikel verf&uuml;gbar.';
 $lang['info_fieldproblems'] = 'Bei einem oder mehreren benutzerdefinierten Feldern wurden Probleme festgestellt. Die Aktion wurde erfolgreich abgeschlossen, Sie sollten jedoch die Ursache der Probleme herausfinden.';
-$lang['info_handleimages'] = 'Upon import, if an image filename is found in a field column, should it be moved from the source location, watermarked, thumbnailed, and the field type changed to &quot;image&quot;';
-$lang['info_imagepath'] = 'The path (relative to the uploads directory) where images referred to in the import file, can be found';
-$lang['info_import_test_passed'] = 'A brief test as been performed on the input file specified, and everything appears to be correct.<br/>This is no indication that there are no errors in the file.';
+$lang['info_handleimages'] = 'Sollen beim Import in einer Spalte gefundene Bilddateien von der Quellposition verschoben, mit Wasserzeichen versehen und ein Vorschaubild erstellt und der Feldtyp auf &quot;Bild&quot; gesetzt werden';
+$lang['info_hierpage'] = 'Diese Seite f&uuml;r Hierarchieansichten verwenden.  Die Seiten-ID wird in der URL nicht verwendet.';
+$lang['info_imagepath'] = 'Ein Pfad (relativ zum Uploads Verzeichnis) in dem die in der Importdatei angegebenen Bilder liegen';
+$lang['info_import_test_passed'] = 'Die angegebene Eingabedatei wurde einem Kurztest unterzogen und alles scheint in Ordnung zu sein.<br/>Dies ist kein Indiz daf&uuml;r, das die Datei fehlerfrei ist.';
+$lang['info_prettyhierurls'] = 'Den Hierarchienamen in die URL einf&uuml;gen';
 $lang['info_price_adjustment'] = 'G&uuml;ltige Eingaben sind +-*#.##';
-$lang['info_prodnotfound'] = 'This option determines the behaviour of the website if a product detail view is accessed directly by URL, and that product for whatever reason (disabled, deleted, etc) cannot be accessed.';
+$lang['info_prodnotfound'] = 'Wie wird ein direkter Aufruf einer Artikeldetailseite per URL behandelt, wenn der Artikel - aus welchen Gr&uuml;nden auch immer (deaktiviert, gel&ouml;scht, usw) - nicht verf&uuml;gbar ist.';
 $lang['info_publicfield'] = '&Ouml;ffentliche Felder sind auf der Webseite f&uuml;r jeden sichtbar.';
 $lang['label'] = 'Beschriftung';
 $lang['label_skip'] = '&Uuml;berspringen';
@@ -208,7 +228,9 @@ $lang['nextpage'] = '>';
 $lang['no'] = 'Nein';
 $lang['nonamegiven'] = 'Es wurde kein Name angegeben';
 $lang['none'] = 'Keines';
+$lang['nothing_selectd'] = 'Nichts ausgew&auml;hlt';
 $lang['of'] = 'Von';
+$lang['operation_complete'] = 'Vorgang abgeschlossen';
 $lang['page'] = 'Seite';
 $lang['page_of'] = 'Seite %s von %s';
 $lang['page_limit'] = 'Seiten-Anzahl';
@@ -220,10 +242,12 @@ $lang['param_action'] = 'Legen Sie das Verhalten des Moduls fest. M&ouml;gliche
   <li>details - zeigt die Detailansicht eines einzelnen Artikels an</li>
 </ul>';
 $lang['param_category'] = 'Wenn dieser Parameter in der <em>default</em> Listenansicht verwendet wird, werden nur Artikel zur angegebenen Kategorie angezeigt. Mehrere Kategorien k&ouml;nnen durch Kommas getrennt angegeben werden. Der Parameter-Name sollte nicht &uuml;bereinstimmen mit dem Namen einer existierenden Kategorie.';
+$lang['param_categoryfield'] = 'Dieser Parameter ist nur in der Kategorie-Ausgabe sinnvoll. Mit ihm k&ouml;nnen Kategorien anhand eines Kategoriefeldes gefiltert werden.  Die Filterung funktioniert nicht wenn gleichzeitig ein &quot;category&quot; oder &quot;category_id&quot; Parameter angegeben wird.  Geben Sie eine kommagetrennte Liste von Kategoriefeldnamen und -werten an.  Bsp.:  categorylist=&quot;Feldname:Wert,Weiterer Feldname:Wert&quot;';
 $lang['param_categorylisttemplate'] = 'Dieser Parameter ist nur in der Kategorie-Ausgabe sinnvoll. Er wird benutzt, um das Template anzugeben, welches verwendet werden soll. Wenn kein Wert angegeben ist, wird das Default-Template verwendet.';
-$lang['param_categorylistdtltemplate'] = 'Useful only with the categorylist actions, this parameter indicates the template that should be used for the display of the category details.  This uses a category list template..  If no value is specified then the current default template of that type is used.';
+$lang['param_categorylistdtltemplate'] = 'Dieser Parameter ist nur in der Kategorie-Ausgabe sinnvoll.  Er gibt das Kategorielisten-Template an, das f&uuml;r die Anzeige von Kategoriedetails verwendet werden soll.  Wenn kein Wert angegeben ist, wird das Standard-Template verwendet.';
 $lang['param_detailpage'] = 'Dies legt die Seiten-ID (pageid) oder den Alias (alias) fest, welche(r) benutzt werden soll, um die Detailansicht auszugeben.';
 $lang['param_detailtemplate'] = 'Dieser Parameter wird verwendet, um das Template festzulegen, welches f&uuml;r die Artikel-Detailansicht verwendet werden soll. Ohne Vorgabe wird das Standard-Template verwendet.';
+$lang['param_excludecat'] = 'Applicable only to the default (summary) view, this parameter will allow excluding products that are in a specific category from the result. A comma separated list of category names is allowed. This parameter can work in conjunction with the category parameter to provide a list of the products that are in this category, but not in that category';
 $lang['param_field'] = 'Used only in the <em>fieldlist</em> action, this parameter is required to specify the name of a user defined property to create a list from.';
 $lang['param_fieldval'] = 'Used only in the <em>default</em> action, this parameter allows specifying a field value to limit results by.  Special values for this field are &quot;::null::&quot; &quot;::notnull::&quot;';
 $lang['param_hierarchy'] = 'Dieser Parameter ist nur in der <em>default</em>-Ansicht sinnvoll. Er wird verwendet, um nur Artikel anzuzeigen, die einer bestimmten Hierarchie angeh&ouml;ren. Dabei k&ouml;nnen Wildcards verwendet werden, um &uuml;bergeordnete/untergeordnete Beziehungen ebenfalls anzuzeigen. Z.B. gibt {Products hierarchy=&#039;LKWs*&#039;} eine Zusammenfassung aller LKWs aus, einschlie&szlig;lich aller untergeordneten Elemente der Hierarchie. Genauso gibt {Products hierarchy=&#039;*LKWs&#039;} eine Zusammenfassung aller LKWs aus, einschlie&szlig;lich der &uuml;bergeordneten Elemente in der Hierarchie.';
@@ -232,6 +256,7 @@ $lang['param_inline'] = 'Useful only with the search action, this parameter spec
 $lang['param_pagelimit'] = 'Dieser Parameter ist nur in der <em>default</em>-Ausgabe sinnvoll. Er legt fest, wie viele Elemente pro Seite angezeigt werden sollen.';
 $lang['param_parent'] = 'Dieser Parameter ist nur in der <em>hierarchy</em>-Ausgabe sinnvoll. Er legt die Hierarchie-ID fest, ab welcher die Artikel ausgegeben werden sollen.';
 $lang['param_productid'] = 'Dieser Parameter ist nur in der <em>detail</em> Artikelansicht sinnvoll. Er legt fest, welcher Artikel angezeigt werden soll.';
+$lang['param_productlist'] = 'Applicable only to the default (summary) view, this parameter allows specifying a comma separated list of integer product ids to display.  No pagination or sorting is performed on these values, and if specified the other filtering parameters to the summary view are ignored.';
 $lang['param_resultpage'] = 'Applicable only to the search, and category list actions, this parameter specifies a page id or alias to use to display the summary results';
 $lang['param_searchfield'] = 'Applicable only to the search action, this parameter may contain a comma separated list of field names to include in the search';
 $lang['param_searchformtemplate'] = 'Applicable only to the search action, thisparameter allows specifying a non default search form template';
@@ -283,7 +308,7 @@ $lang['prompt_autopreviewimg'] = 'Automatisch Vorschaubilder der Bilder erstelle
 $lang['prompt_autopreviewimg_size'] = 'Maximale Gr&ouml;&szlig;e (gr&ouml;&szlig;te Ausdehnung) des Vorschaubildes.';
 $lang['prompt_autowatermark'] = 'Automatisch Wasserzeichen auf den Bildern erzeugen';
 $lang['prompt_applicable'] = 'Aktivierung per Voreinstellung f&uuml;r alle neuen Artikel';
-$lang['prompt_batchsize'] = 'Batch Size';
+$lang['prompt_batchsize'] = 'Blockgr&ouml;&szlig;e';
 $lang['prompt_cart_module'] = 'Cart-Modul';
 $lang['prompt_cart_module_params'] = 'Cart-Modul Parameter';
 $lang['prompt_createcategories'] = 'Kategorien erstellen';
@@ -300,7 +325,7 @@ $lang['prompt_detailpage'] = 'Voreingestellte Detail-Seite';
 $lang['prompt_detailsfor'] = 'Details f&uuml;r %s';
 $lang['prompt_duplicateproducts'] = 'Wie sollen doppelte Produkte gehandhabt werden?';
 $lang['prompt_false'] = 'Nein';
-$lang['prompt_handleimages'] = 'Handle images?';
+$lang['prompt_handleimages'] = 'Bilder verarbeiten?';
 $lang['prompt_imagepath'] = 'Bilderpfad';
 $lang['prompt_lengthunits'] = 'L&auml;ngeneinheiten';
 $lang['prompt_notfound_behavior'] = 'Welche Aktion soll ausgef&uuml;hrt werden, wenn ein Artikel nicht angezeigt werden konnte?';
@@ -309,16 +334,19 @@ $lang['prompt_notfound_301'] = 'Eine 301er Weiterleitung erzeugen';
 $lang['prompt_notfound_errormsg'] = 'Eine Fehlermeldung anzeigen';
 $lang['prompt_notfound_msg'] = 'Fehlermeldung, wenn ein Artikel nicht gefunden werden konnte';
 $lang['prompt_notfound_page'] = 'Seite f&uuml;r dauerhafte Umleitung?';
+$lang['prompt_hierpage'] = 'Voreingestellte Seite f&uuml;r Hierarchie-Listenansicht';
+$lang['prompt_prettyhierurls'] = 'Suchmaschinenfreundliche URLs (Pretty URLS) f&uuml;r Hierarchieansichten verwenden';
 $lang['prompt_prod_detailpage'] = 'Standardseite f&uuml;r Produkt Detailansicht';
 $lang['prompt_products_matching'] = 'Produkte passend %s';
+$lang['prompt_sku_required'] = 'Art.-Nr ist ein Pflichtfeld (muss bei allen Artikeln angegeben werden)';
 $lang['prompt_summarypagelimit'] = 'Voreingestelltes Produktlimit in der Listenansicht';
 $lang['prompt_summarysortorder'] = 'Voreingestellte Sortier-Reihenfolge in der Listenansicht';
 $lang['prompt_summarysorting'] = 'Voreingestelltes Sortier-Feld in der Listenansicht';
 $lang['prompt_template'] = 'Template-Quelle';
 $lang['prompt_true'] = 'Ja';
-$lang['prompt_urlprefix'] = 'Prefix to use on all URLS targeted to this this module';
-$lang['prompt_use_detailpage_for_search'] = 'Use this page for search results too <em>(overrides the searchresults page parameter in the search module)</em>';
-$lang['prompt_usehierpathurls'] = 'Use Hierarchy Path in Product Detail URLS';
+$lang['prompt_urlprefix'] = 'Diese Zeichenkette in alle URLs einf&uuml;gen, die sich auf dieses Modul beziehen';
+$lang['prompt_use_detailpage_for_search'] = 'Diese Seite auch f&uuml;r Suchergebnisse verwenden <em>(Ersetzt den <code>resultpage</code> Parameter des Suche Moduls)</em>';
+$lang['prompt_usehierpathurls'] = 'Die Hierarchienamen in die URL von Artikeldetails einf&uuml;gen';
 $lang['prompt_weightunits'] = 'Gewichts-Einheit';
 $lang['public'] = 'Ist dies ein &ouml;ffentliches Feld?';
 $lang['published'] = 'Ver&ouml;ffentlicht';
@@ -333,7 +361,10 @@ $lang['search_name'] = 'Suche nach Eigenschaft Name';
 $lang['search_price'] = 'Preisspanne';
 $lang['searchtemplate_addedit'] = 'Hinzuf&uuml;gen/Bearbeiten Suchformular Template';
 $lang['searchtemplates'] = 'Suchformular Templates';
+$lang['select_all'] = 'Alle ausw&auml;hlen';
 $lang['select_one'] = 'Bitte ausw&auml;hlen';
+$lang['setdraft'] = 'Status auf &quot;Enturf&quot; setzen';
+$lang['setpublished'] = 'Status auf &quot;Ver&ouml;ffentlicht&quot; setzen';
 $lang['sku'] = 'Art.-Nr.';
 $lang['sort_by'] = 'Sortiert nach';
 $lang['sort_order'] = 'Sortier-Reihenfolge';
@@ -374,10 +405,10 @@ $lang['view'] = 'Anzeigen';
 $lang['viewable_fields'] = 'W&auml;hlen Sie benutzerdefinierte Felder in der Tabellenansicht';
 $lang['watermark_location'] = 'Platzierung des Wasserzeichens';
 $lang['weight'] = 'Gewicht';
+$lang['with_selected'] = 'Ausgew&auml;hlte Eintr&auml;ge';
 $lang['yes'] = 'Ja';
-$lang['qca'] = 'P0-1458450664-1284573084918';
-$lang['utmz'] = '156861353.1292514844.633.43.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
-$lang['utma'] = '156861353.1164361908.1285153768.1292748011.1292751775.658';
+$lang['qca'] = 'P0-1362779760-1309265682636';
+$lang['utma'] = '156861353.1681295217.1311961821.1312317698.1312377783.16';
+$lang['utmz'] = '156861353.1311961821.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.2.10.1292751775';
 ?>
\ No newline at end of file
