@@ -258,12 +258,12 @@ $lang['param_action'] = 'Specify the behaviour of the module.  Possible values a
   <li>search - Display a form to allow searching products on various criterium</li>
 </ul>';
 $lang['param_category'] = 'N&aring;r benyttet med <em>standard</em> sammendragsmodus vil denne parameter, som skal v&aelig;re lik navnet p&aring; en eksisterende kategori, bli benyttet for &aring; vise kun de produktene som er i denne kategorien. (en kommaseparert liste kan oppgis) Denne parameteren kan ogs&aring; benyttes med categorylist handlingen for &aring; begrense utdata til de spesifiserte produktkatagoriene.';
-$lang['param_categoryfield'] = 'Applicable only to the &quot;categorylist&quot; action, this parameter can be used to filter categories based on the value of a category field.  It will not work in conjunction with the &quot;category&quot; or &quot;category_id&quot; parameters.   The syntax of this parameter is a comma separated list of field names, and field values.  i.e:  categorylist=&quot;field name:value,field name 2:value 2&quot;';
+$lang['param_categoryfield'] = 'Gjelder kun til &quot;categorylist&quot; handling, hvor denne parameteren kan brukes til &aring; filtrere kategorier basert p&aring; verdien av et kategorifelt. Dette vil ikke fungere i forbindelse med &quot;kategori&quot; eller &quot;category_id&quot; parametere. Syntaksen for denne parameteren er en kommaseparert liste med feltnavn, og feltverdier. dvs.: categorylist=&amp;quot;feltnavnet:verdi,feltnavn2:verdien 2&amp;quot;';
 $lang['param_categorylisttemplate'] = 'Med kategoriliste  og fieldlist handlingene, vil denne parameter indikere malen som skal benyttes for visning. Om ingen verdi er oppgitt vil n&aring;v&aelig;rende standard mal av denne type bli benyttet.';
 $lang['param_categorylistdtltemplate'] = 'Kan kun benyttes med categorylist handlingene, hvor denne parameteren indikerer malen som skal benyttes for visning av kategoridetaljer. Dette benytter en katagorilistemal.. Om ingen verdi er spesifisert s&aring; vil n&aring;v&aelig;rende standardmal av denne typen bli benyttet.';
 $lang['param_detailpage'] = 'Dette spesifiserer sideid&#039;en eller sidealias som skal benyttes for &aring; vise detaljrapporten. Dette kan benyttes med <em>default</em> eller s&oslash;k handlingene.';
 $lang['param_detailtemplate'] = 'Denne parameter spesifiserer malen som skal benyttes for detaljmodus visning. Om ingen verdi er oppgitt vil n&aring;v&aelig;rende standard mal av denne type bli benyttet. Denne parameter har ingen virkning n&aring;r vakre urler er p&aring;sl&aring;tt.';
-$lang['param_excludecat'] = 'Applicable only to the default (summary) view, this parameter will allow excluding products that are in a specific category from the result. A comma separated list of category names is allowed. This parameter can work in conjunction with the category parameter to provide a list of the products that are in this category, but not in that category';
+$lang['param_excludecat'] = 'Gjelder kun til standard (sammendrag) visning, hvor denne parameteren vil tillate unntak av produkter som er i en bestemt kategori fra resultatet. En kommaseparert liste med kategorinavn er tillatt. Denne parameteren kan fungere sammen med kategori-parameteren for &aring; gi en liste over produkter som er i denne kategorien, men ikke i den kategorien';
 $lang['param_field'] = 'Benyttet kun i <em>fieldlist</em> handlingen, der denne parameter er p&aring;krevd for &aring; spesifisere navnet p&aring; en brukerdefinert egenskap som det skal lages en liste fra.';
 $lang['param_fieldval'] = 'Kun benyttet i <em>standard</em> handlinge, hvor denne parameter tillater &aring; spesifisere en feltverdi &aring; begrense resultater etter. Spesialverdier for dette feltet er &quot;::null::&quot; &quot;::notnull::&quot;';
 $lang['param_hierarchy'] = 'Kan kun benyttes i <em>default</em> og hierarki handlinger. Denne parameter har to oppgaver - den spesifiserer at kun artikler i denne lokasjonen i hierarkiet skal vises.  Jokertegn kan benyttes s&aring; du ogs&aring; kan spesifisere foreldre/barn relasjoner. F.eks. {Products hierarchy=&#039;trucks*&#039;} vil lage en sammendragsrapport med alle trucks, inkludert barna i hierarkiet.  P&aring; samme m&aring;te, {Products hierarchy=&#039;*trucks&#039;} vil vise en sammendragsrapport med alle trucks og alle produkter tilh&oslash;rende enhver foreldre i hierarkiet. N&aring;r benyttet med hierarkihandlingen s&aring; kan denne parameter gi en liste med hierarkinavn for &aring; vise akkurat disse. F.eks. {Products action=hierarchy hierarchy=&#039;trucks,cars&#039;}';
@@ -425,9 +425,9 @@ $lang['viewable_fields'] = 'Velg brukerdefinerte felter som skal vises i tabelle
 $lang['watermark_location'] = 'Vannmerke lokasjon';
 $lang['weight'] = 'Vekt';
 $lang['yes'] = 'Ja';
-$lang['utmz'] = '156861353.1302963072.3784.82.utmcsr=cmsms.eu|utmccn=(referral)|utmcmd=referral|utmcct=/';
-$lang['utma'] = '156861353.179052623084110100.1210423577.1306670563.1306673866.3886';
-$lang['qca'] = '1210971690-27308073-81952832';
+$lang['qca'] = 'P0-536849115-1307983495210';
+$lang['utma'] = '156861353.1438284364.1309196715.1309554925.1309558965.15';
+$lang['utmz'] = '156861353.1307983495.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
 $lang['utmc'] = '156861353';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
