@@ -96,6 +96,7 @@ $lang['error_product_skuused'] = 'Deze Uitlevereenheid is al in gebruik door een
 $lang['error_price_adjustment'] = 'Ongeldige prijs aanpassing van item %s';
 $lang['error_sku_required'] = 'Voer een unieke SKU in';
 $lang['error_upload_failed'] = 'Upload mislukt: %s';
+$lang['exclude_categories'] = 'Sluit producten in de geselecteerde categori&euml;n uit van de resultaten';
 $lang['expire_six_months'] = 'Na zes maanden';
 $lang['expire_one_year'] = 'Na een jaar';
 $lang['expire_two_year'] = 'Na twee jaar';
@@ -214,13 +215,13 @@ $lang['info_delimiter'] = 'Specificeer het karakter(s) dat gebruikt moet worden
 $lang['info_duplicateproducts'] = 'Specificeer hoe het systeem moet handelen als er een product voorkomt met dezelfde naam in het CSV file';
 $lang['info_fielddefs_tab'] = '<strong>Opmerking:</strong> De hier aanwezige velden zijn beschikbaar voor alle producten.';
 $lang['info_fieldproblems'] = 'Er is probleem ontstaan met het verwerken van een of meer aangemaakte velden.  Deze actie is correct uitgevoerd. maar het is verstandig alles te controleren en eventueel te herstellen.';
-$lang['info_handleimages'] = 'Upon import, if an image filename is found in a field column, should it be moved from the source location, watermarked, thumbnailed, and the field type changed to &quot;image&quot;';
+$lang['info_handleimages'] = 'Als bij een import een bestandsnaam van een afbeelding wordt gevonden, moet het dan verplaatst worden van de bronlocatie, worden gewatermerkt, gethumnailed of het bestandstype worden gewijzigd naar &quot;image&quot;.';
 $lang['info_hierpage'] = 'Gebruik deze pagina voor de hie&auml;rchische weergave. De paginaid zal niet worden weergegeven in de URL.';
 $lang['info_imagepath'] = 'In dit pad (gezien vanaf de uploads-map) kunnen de afbeeldingen worden gevonden die zijn opgegeven in het ge&iuml;mporteerde bestand.';
 $lang['info_import_test_passed'] = 'Een korte test heeft plaatsgevonden op het geselecteerde geselecteerde bestand en alles lijkt in orde.<br/>Dit is echter geen garantie dat er geen fouten in het bestand aanwezig zijn.';
 $lang['info_prettyhierurls'] = 'Voeg de hie&auml;rchie naam toe aan de URL';
 $lang['info_price_adjustment'] = 'Geaccepteerde waarden zijn +-*#.##';
-$lang['info_prodnotfound'] = 'This option determines the behaviour of the website if a product detail view is accessed directly by URL, and that product for whatever reason (disabled, deleted, etc) cannot be accessed.';
+$lang['info_prodnotfound'] = 'Deze optie bepaald het gedrag van de website wanneer een detailweergave van een product rechtstreeks wordt bezocht met een URL en dat product om een bepaalde reden (uitgeschakeld, verwijderd, etc.) niet kan worden bezocht.';
 $lang['info_publicfield'] = 'Publieke velden zijn zichtbaar voor het publiek';
 $lang['label'] = 'Label ';
 $lang['label_skip'] = 'Sla over';
@@ -240,7 +241,9 @@ $lang['nextpage'] = '>';
 $lang['no'] = 'Nee';
 $lang['nonamegiven'] = 'Er is geen naam ingevuld';
 $lang['none'] = 'Geen';
+$lang['nothing_selectd'] = 'Niets geselecteerd';
 $lang['of'] = 'Van';
+$lang['operation_complete'] = 'Operatie uitgevoerd';
 $lang['page'] = 'Pagina';
 $lang['page_of'] = 'Pagina %s van %s';
 $lang['page_limit'] = 'Pagina Limiet';
@@ -259,7 +262,7 @@ $lang['param_action'] = 'Specificeer de werking van de module.  Mogelijke waarde
 
 </ul>';
 $lang['param_category'] = 'When used in the <em>default</em> summary mode, this parameter, which should match the name of an existing category will be used to display only those products that are in that categoory. (a comma seperated list can be supplied)';
-$lang['param_categoryfield'] = 'Applicable only to the &quot;categorylist&quot; action, this parameter can be used to filter categories based on the value of a category field.  It will not work in conjunction with the &quot;category&quot; or &quot;category_id&quot; parameters.   The syntax of this parameter is a comma separated list of field names, and field values.  i.e:  categorylist=&quot;field name:value,field name 2:value 2&quot;';
+$lang['param_categoryfield'] = 'Alleen van toepassing op de &quot;categorylist&quot; actie, deze parameter kan gebruikt worden om categori&euml;n te filteren op basis van de waarde van het categorieveld. Het werkt niet in combinatie met de &quot;category&quot; of de &quot;category_id&quot; parameters. De syntax van deze parameter is een kommagescheiden lijst met veldnamen en veldwaarden.  Bijvoorbeeld:  categorylist=&quot;veldnaam:waarde,veldnaam 2:waarde 2&quot;';
 $lang['param_categorylisttemplate'] = 'Useful only with the categorylist action, this parameter indicates the template that should be used for the display.  If no value is specified then the current default template of that type is used.';
 $lang['param_categorylistdtltemplate'] = 'Useful only with the categorylist actions, this parameter indicates the template that should be used for the display of the category details.  This uses a category list template..  If no value is specified then the current default template of that type is used.';
 $lang['param_detailpage'] = 'This specifies the pageid or alias that should be used to display the detail report.';
@@ -379,7 +382,10 @@ $lang['search_name'] = 'Zoekeigenschap Naam';
 $lang['search_price'] = 'Prijs marge';
 $lang['searchtemplate_addedit'] = 'Toevoegen/wijzigen Zoekformulier sjabloon';
 $lang['searchtemplates'] = 'Zoek Sjablonen';
+$lang['select_all'] = 'Selecteer akkes';
 $lang['select_one'] = 'Kies &eacute;&eacute;n';
+$lang['setdraft'] = 'Markeer als concept';
+$lang['setpublished'] = 'Markeer als gepubliceerd';
 $lang['sku'] = 'Uitlevereenheid ';
 $lang['sort_by'] = 'Sorteer op';
 $lang['sort_order'] = 'Sorteervolgorde';
@@ -420,10 +426,11 @@ $lang['view'] = 'Bekijk';
 $lang['viewable_fields'] = 'Selecteer velden om in het tabel te tonen';
 $lang['watermark_location'] = 'Plaats Watermerk';
 $lang['weight'] = 'Gewicht';
+$lang['with_selected'] = 'Met geselecteerden';
 $lang['yes'] = 'Ja';
-$lang['utma'] = '156861353.1852221271.1287479092.1305382006.1305392937.148';
-$lang['utmz'] = '156861353.1305382016.147.92.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
-$lang['qca'] = 'P0-161031897-1287479092171';
+$lang['utma'] = '156861353.805332592.1309943374.1309943374.1309943374.1';
+$lang['utmz'] = '156861353.1309794590.3.3.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/projects/file_listing';
+$lang['qca'] = 'P0-1408926661-1309528475256';
 $lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
