@@ -42,29 +42,10 @@ class product_ops
 {
   static private $_fielddefs;
 
-  static private function &_get_db()
-  {
-    global $gCms;
-    $db =& $gCms->GetDb();
-    return $db;
-  }
-
-
-  static private function &_get_module()
-  {
-    global $gCms;
-    $res = null;
-    if( isset($gCms->modules['Products']['object']) )
-      {
-	$res = $gCms->modules['Products']['object'];
-      }
-    return $res;
-  }
-
 
   static public function is_valid_category($name)
   {
-    $db =& self::_get_db();
+    $db = cmsms()->GetDb();
     $query = 'SELECT id FROM '.cms_db_prefix().'module_products_categories
                WHERE name = ?';
     $tmp = $db->GetOne($query,array($name));
@@ -75,7 +56,7 @@ class product_ops
 
   public static function is_valid_product_id($pid)
   {
-    $db =& self::_get_db();
+    $db = cmsms()->GetDb();
     $query = 'SELECT id FROM '.cms_db_prefix().'module_products 
                WHERE id = ?';
     $tmp = $db->Execute($query,array($pid));
@@ -96,7 +77,7 @@ class product_ops
       }
     $tmp3 = implode(' | ',$tmp2);
 
-    $db =& self::_get_db();
+    $db = cmsms()->GetDb();
     $query = 'SELECT id FROM '.cms_db_prefix().'module_products_hierarchy
                WHERE long_name = ?';
     $tmp = $db->GetOne($query,array($tmp3));
@@ -107,7 +88,7 @@ class product_ops
 
   public static function check_sku_used($sku,$productid = '',$productonly = false)
   {
-    $db =& self::_get_db();
+    $db = cmsms()->GetDb();
     $query = 'SELECT id FROM '.cms_db_prefix().'module_products
                WHERE sku = ?';
     $parms = array($sku);
@@ -171,7 +152,7 @@ class product_ops
   // creates a product detail url.
   static public function pretty_url($pid,$returnid = '')
   {
-    $module = self::_get_module();
+    $module = cms_utils::get_module('Products');
     $product = $module->GetProduct($pid);
     if( !$product ) return;
     $db = $module->GetDB();
@@ -262,7 +243,7 @@ class product_ops
 
   public static function create_hierarchy_breadcrumb($id,$product_id, $hierpage, $delim = ' &gt; ')
   {
-    $module = self::_get_module();
+    $module = cms_utils::get_module('Products');
     $tmp = array();
     $hierarchy_path = self::get_product_hierarchy_path($product_id);
     if( !$hierarchy_path ) return false;
@@ -280,7 +261,7 @@ class product_ops
   public static function get_search_result($returnid, $productid, $attr = '')
   {
     $result = array();
-    $mod = self::_get_module();
+    $mod = cms_utils::get_module('Products');
     
     if ($attr != 'product')
       {
@@ -292,7 +273,7 @@ class product_ops
 	$returnid = '';
       }
 
-    $db =& $mod->GetDb();
+    $db = $mod->GetDb();
     $q = "SELECT product_name FROM ".cms_db_prefix()."module_products WHERE
 			      id = ?";
     $dbresult = $db->Execute( $q, array( $productid ) );
@@ -322,7 +303,7 @@ class product_ops
       {
 	return cg_ecomm::get_currency_symbol();
       }
-    $mod = self::_get_module();
+    $mod = cms_utils::get_module('Products');
     return $mod->GetPreference('products_currencysymbol','$');
   }
 
@@ -333,7 +314,7 @@ class product_ops
       {
 	return cg_ecomm::get_weight_units();
       }
-    $mod = self::_get_module();
+    $mod = cms_utils::get_module('Products');
     return $mod->GetPreference('products_weightunits','kg');
   }
 
@@ -344,7 +325,7 @@ class product_ops
       {
 	return cg_ecomm::get_length_units();
       }
-    $mod = self::_get_module();
+    $mod = cms_utils::get_module('Products');
     return $mod->GetPreference('products_lengthunits','kg');
   }
 
@@ -356,7 +337,7 @@ class product_ops
 	global $gCms;
 	$db = $gCms->GetDb();
 	
-	$query = 'SELECT * FROM '.cms_db_prefix().'module_products_fielddefs';
+	$query = 'SELECT * FROM '.cms_db_prefix().'module_products_fielddefs ORDER BY item_order';
 	self::$_fielddefs = $db->GetArray($query);
       }
     return self::$_fielddefs;
