@@ -274,18 +274,8 @@ $this->SetPreference('allowed_imagetypes','jpg,jpeg,gif,png');
 $this->SetPreference('allowed_filetypes','pdf,doc,txt,jpg,jpeg,gif,png');
 $this->SetPreference('autothumbnail',1);
 $this->SetPreference('deleteproductfiles',1);
-$this->SetPreference('cartmoduleparams','product=$entry->id');
 
-// find a cart module
-$modules =& $gCms->modules;
-foreach( $modules as $one )
-{
-  if( !isset($one['object']) ) continue;
-  $obj =& $one['object'];
-  if( !is_object($obj) ) continue;
-  if( !method_exists($obj,'IsCartModule') ) continue;
-  if( !$obj->IsCartModule() ) continue;
-  $this->SetPreference('cartmodule',$obj->GetName());
-  break;
-}
+#
+# EOF
+#
 ?>
